@@ -2,7 +2,7 @@
  * MAT File I/O Utility Functions
  */
 /*
- * Copyright (c) 2005-2019, Christopher C. Hulbert
+ * Copyright (c) 2005-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,20 +27,26 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "matio_private.h"
+#if defined(_WIN32) && defined(_MSC_VER)
+#   define WIN32_LEAN_AND_MEAN
+#   define NOGDI
+#   include <Windows.h>
+#endif
 #include <stdlib.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
-#include "matio_private.h"
 
 #if !defined(HAVE_VA_COPY) && defined(HAVE___VA_COPY)
-#    define va_copy(d,s) __va_copy(d,s)
+#   define va_copy(d,s) __va_copy(d,s)
 #elif !defined(HAVE_VA_COPY)
-#    define va_copy(d,s) memcpy(&(d),&(s),sizeof(va_list))
+#   define va_copy(d,s) memcpy(&(d),&(s),sizeof(va_list))
 #endif
 
 static void (*logfunc)(int log_level, char *message ) = NULL;
 static const char *progname = NULL;
+static char *strdup_vprintf(const char *format, va_list ap) MATIO_FORMATATTR_VPRINTF;
 
 /** @brief Allocates and prints to a new string
  *
@@ -49,7 +55,7 @@ static const char *progname = NULL;
  * @param ap variable argument list
  * @return Newly allocated string with format printed to it
  */
-char *
+static char *
 strdup_vprintf(const char* format, va_list ap)
 {
     va_list ap2;
@@ -68,22 +74,43 @@ strdup_vprintf(const char* format, va_list ap)
     return buffer;
 }
 
-/** @brief Allocates and prints to a new string using printf format
+#if defined(_WIN32) && defined(_MSC_VER)
+/** @brief Convert from narrow UTF-8 string to wide string
  *
  * @ingroup mat_util
- * @param format format string
- * @return Pointer to resulting string, or NULL if there was an error
+ * @param src narrow string
+ * @return Pointer to resulting wide string, or NULL if there was an error
  */
-char *
-strdup_printf(const char* format, ...)
+wchar_t*
+utf82u(const char* src)
 {
-    char* buffer;
-    va_list ap;
-    va_start(ap, format);
-    buffer = strdup_vprintf(format, ap);
-    va_end(ap);
-    return buffer;
+    if ( NULL != src ) {
+        int srcLen = (int)strlen(src);
+        if ( 0 != srcLen ) {
+            int rc = MultiByteToWideChar(CP_UTF8, 0, src, srcLen, 0, 0);
+            if ( 0 != rc ) {
+                wchar_t* w = (wchar_t*)malloc(sizeof(wchar_t)*(rc + 1));
+                if ( NULL != w ) {
+                    w[rc] = L'\0';
+                    rc = MultiByteToWideChar(CP_UTF8, 0, src, srcLen, w, rc);
+                    if ( 0 != rc ) {
+                        return w;
+                    } else {
+                        free(w);
+                    }
+                }
+            }
+        } else {
+            wchar_t* w = (wchar_t*)malloc(sizeof(wchar_t));
+            if ( NULL != w ) {
+                w[0] = L'\0';
+                return w;
+            }
+        }
+    }
+    return NULL;
 }
+#endif
 
 /** @brief Default logging function
  *
@@ -405,6 +432,7 @@ int
 Mat_LogInit( const char *prog_name )
 {
     logfunc = &mat_logfunc;
+    progname = prog_name;
 #if defined(MAT73) && MAT73
     H5Eset_auto(H5E_DEFAULT, mat_h5_log_cb, NULL);
 #endif
