@@ -3,7 +3,7 @@
  * @ingroup MAT
  */
 /*
- * Copyright (c) 2005-2018, Christopher C. Hulbert
+ * Copyright (c) 2005-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,10 +31,9 @@
 #ifndef MATIO_H
 #define MATIO_H
 
+#include "matio_pubconf.h"
 #include <stdlib.h>
 #include <stdio.h>
-#include "matio_pubconf.h"
-
 #include <stdarg.h>
 
 #ifdef __cplusplus
@@ -205,17 +204,17 @@ typedef struct matvar_t {
  * @ingroup MAT
  */
 typedef struct mat_sparse_t {
-    int nzmax;               /**< Maximum number of non-zero elements */
-    mat_int32_t *ir;         /**< Array of size nzmax where ir[k] is the row of
+    mat_uint32_t  nzmax;     /**< Maximum number of non-zero elements */
+    mat_uint32_t *ir;        /**< Array of size nzmax where ir[k] is the row of
                                *  data[k].  0 <= k <= nzmax
                                */
-    int nir;                 /**< number of elements in ir */
-    mat_int32_t *jc;         /**< Array size N+1 (N is number of columns) with
+    mat_uint32_t  nir;       /**< number of elements in ir */
+    mat_uint32_t *jc;        /**< Array size N+1 (N is number of columns) with
                                *  jc[k] being the index into ir/data of the
                                *  first non-zero element for row k.
                                */
-    int   njc;               /**< Number of elements in jc */
-    int   ndata;             /**< Number of complex/real data values */
+    mat_uint32_t  njc;       /**< Number of elements in jc */
+    mat_uint32_t  ndata;     /**< Number of complex/real data values */
     void *data;              /**< Array of data elements */
 } mat_sparse_t;
 
@@ -227,18 +226,40 @@ typedef struct mat_sparse_t {
 #define MATIO_LOG_LEVEL_DEBUG    1 << 4
 /** @endcond */
 
+/** @cond 0 */
+#define MATIO_E_NO_ERROR 0
+#define MATIO_E_UNKNOWN_ERROR 1
+#define MATIO_E_GENERIC_READ_ERROR 2
+#define MATIO_E_GENERIC_WRITE_ERROR 3
+#define MATIO_E_INDEX_TOO_BIG 4
+#define MATIO_E_FILE_FORMAT_VIOLATION 5
+#define MATIO_E_FAIL_TO_IDENTIFY 6
+#define MATIO_E_BAD_ARGUMENT 7
+#define MATIO_E_OUTPUT_BAD_DATA 8
+#define MATIO_E_OPERATION_NOT_SUPPORTED 13
+#define MATIO_E_OUT_OF_MEMORY 14
+#define MATIO_E_BAD_VARIABLE_NAME 15
+#define MATIO_E_OPERATION_PROHIBITED_IN_WRITE_MODE 16
+#define MATIO_E_OPERATION_PROHIBITED_IN_READ_MODE 17
+#define MATIO_E_WRITE_VARIABLE_DOES_NOT_EXIST 18
+#define MATIO_E_READ_VARIABLE_DOES_NOT_EXIST 19
+#define MATIO_E_FILESYSTEM_COULD_NOT_OPEN 20
+#define MATIO_E_FILESYSTEM_COULD_NOT_OPEN_TEMPORARY 21
+#define MATIO_E_FILESYSTEM_COULD_NOT_REOPEN 22
+#define MATIO_E_BAD_OPEN_MODE 23
+#define MATIO_E_FILESYSTEM_ERROR_ON_CLOSE 24
+/** @endcond */
+
 /* Library function */
 EXTERN void Mat_GetLibraryVersion(int *major,int *minor,int *release);
 
 /* io.c */
-EXTERN char  *strdup_vprintf(const char *format, va_list ap) MATIO_FORMATATTR_VPRINTF;
-EXTERN char  *strdup_printf(const char *format, ...) MATIO_FORMATATTR_PRINTF1;
 EXTERN int    Mat_SetVerbose(int verb, int s);
 EXTERN int    Mat_SetDebug(int d);
 EXTERN void   Mat_Critical(const char *format, ...) MATIO_FORMATATTR_PRINTF1;
 EXTERN MATIO_NORETURN void Mat_Error(const char *format, ...) MATIO_NORETURNATTR MATIO_FORMATATTR_PRINTF1;
 EXTERN void   Mat_Help(const char *helpstr[]);
-EXTERN int    Mat_LogInit(const char *progname);
+EXTERN int    Mat_LogInit(const char *prog_name);
 EXTERN int    Mat_LogClose(void);
 EXTERN int    Mat_LogInitFunc(const char *prog_name,
                   void (*log_func)(int log_level, char *message));
@@ -257,6 +278,7 @@ EXTERN mat_t      *Mat_CreateVer(const char *matname,const char *hdr_str,
 EXTERN int         Mat_Close(mat_t *mat);
 EXTERN mat_t      *Mat_Open(const char *matname,int mode);
 EXTERN const char *Mat_GetFilename(mat_t *mat);
+EXTERN const char *Mat_GetHeader(mat_t *mat);
 EXTERN enum mat_ft Mat_GetVersion(mat_t *mat);
 EXTERN char      **Mat_GetDir(mat_t *mat, size_t *n);
 EXTERN int         Mat_Rewind(mat_t *mat);
