@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2019, Christopher C. Hulbert
+ * Copyright (c) 2008-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@
 
 #include "matioConfig.h"
 #include "matio.h"
-#if defined(HAVE_ZLIB)
+#if HAVE_ZLIB
 #   include <zlib.h>
 #endif
 #if defined(MAT73) && MAT73
@@ -44,10 +44,17 @@
 #   endif
 #endif
 
-#if defined(HAVE_ZLIB) && HAVE_ZLIB
+#if HAVE_ZLIB
 #   define ZLIB_BYTE_PTR(a) ((Bytef *)(a))
 #endif
 
+#if !defined(READ_BLOCK_SIZE)
+#define READ_BLOCK_SIZE (8192)
+#endif
+
+#define _CAT(X, Y) X ## Y
+#define CAT(X, Y) _CAT(X, Y)
+
 /** @if mat_devman
  * @brief Matlab MAT File information
  *
@@ -86,7 +93,7 @@ struct matvar_internal {
     long       datapos;     /**< Offset from the beginning of the MAT file to the data */
     unsigned   num_fields;  /**< Number of fields */
     char     **fieldnames;  /**< Pointer to fieldnames */
-#if defined(HAVE_ZLIB)
+#if HAVE_ZLIB
     z_streamp  z;           /**< zlib compression state */
     void      *data;        /**< Inflated data array */
 #endif
@@ -133,32 +140,32 @@ EXTERN mat_int16_t   Mat_int16Swap(mat_int16_t  *a);
 EXTERN mat_uint16_t  Mat_uint16Swap(mat_uint16_t *a);
 
 /* read_data.c */
-EXTERN int ReadDoubleData(mat_t *mat,double  *data,enum matio_types data_type,
-               int len);
-EXTERN int ReadSingleData(mat_t *mat,float   *data,enum matio_types data_type,
-               int len);
+EXTERN size_t ReadDoubleData(mat_t *mat,double *data,enum matio_types data_type,
+               size_t len);
+EXTERN size_t ReadSingleData(mat_t *mat,float  *data,enum matio_types data_type,
+               size_t len);
 #ifdef HAVE_MAT_INT64_T
-EXTERN int ReadInt64Data (mat_t *mat,mat_int64_t *data,
-               enum matio_types data_type,int len);
+EXTERN size_t ReadInt64Data (mat_t *mat,mat_int64_t *data,
+               enum matio_types data_type,size_t len);
 #endif /* HAVE_MAT_INT64_T */
 #ifdef HAVE_MAT_UINT64_T
-EXTERN int ReadUInt64Data(mat_t *mat,mat_uint64_t *data,
-               enum matio_types data_type,int len);
+EXTERN size_t ReadUInt64Data(mat_t *mat,mat_uint64_t *data,
+               enum matio_types data_type,size_t len);
 #endif /* HAVE_MAT_UINT64_T */
-EXTERN int ReadInt32Data (mat_t *mat,mat_int32_t *data,
-               enum matio_types data_type,int len);
-EXTERN int ReadUInt32Data(mat_t *mat,mat_uint32_t *data,
-               enum matio_types data_type,int len);
-EXTERN int ReadInt16Data (mat_t *mat,mat_int16_t *data,
-               enum matio_types data_type,int len);
-EXTERN int ReadUInt16Data(mat_t *mat,mat_uint16_t *data,
-               enum matio_types data_type,int len);
-EXTERN int ReadInt8Data  (mat_t *mat,mat_int8_t  *data,
-               enum matio_types data_type,int len);
-EXTERN int ReadUInt8Data (mat_t *mat,mat_uint8_t  *data,
-               enum matio_types data_type,int len);
-EXTERN int ReadCharData  (mat_t *mat,char  *data,enum matio_types data_type,
-               int len);
+EXTERN size_t ReadInt32Data (mat_t *mat,mat_int32_t *data,
+               enum matio_types data_type,size_t len);
+EXTERN size_t ReadUInt32Data(mat_t *mat,mat_uint32_t *data,
+               enum matio_types data_type,size_t len);
+EXTERN size_t ReadInt16Data (mat_t *mat,mat_int16_t *data,
+               enum matio_types data_type,size_t len);
+EXTERN size_t ReadUInt16Data(mat_t *mat,mat_uint16_t *data,
+               enum matio_types data_type,size_t len);
+EXTERN size_t ReadInt8Data  (mat_t *mat,mat_int8_t  *data,
+               enum matio_types data_type,size_t len);
+EXTERN size_t ReadUInt8Data (mat_t *mat,mat_uint8_t  *data,
+               enum matio_types data_type,size_t len);
+EXTERN size_t ReadCharData  (mat_t *mat,char  *data,enum matio_types data_type,
+               size_t len);
 EXTERN int ReadDataSlab1(mat_t *mat,void *data,enum matio_classes class_type,
                enum matio_types data_type,int start,int stride,int edge);
 EXTERN int ReadDataSlab2(mat_t *mat,void *data,enum matio_classes class_type,
@@ -167,7 +174,7 @@ EXTERN int ReadDataSlab2(mat_t *mat,void *data,enum matio_classes class_type,
 EXTERN int ReadDataSlabN(mat_t *mat,void *data,enum matio_classes class_type,
                enum matio_types data_type,int rank,size_t *dims,int *start,
                int *stride,int *edge);
-#if defined(HAVE_ZLIB)
+#if HAVE_ZLIB
 EXTERN int ReadCompressedDoubleData(mat_t *mat,z_streamp z,double  *data,
                enum matio_types data_type,int len);
 EXTERN int ReadCompressedSingleData(mat_t *mat,z_streamp z,float   *data,
@@ -205,23 +212,25 @@ EXTERN int ReadCompressedDataSlabN(mat_t *mat,z_streamp z,void *data,
                int rank,size_t *dims,int *start,int *stride,int *edge);
 
 /* inflate.c */
-EXTERN size_t InflateSkip(mat_t *mat, z_streamp z, int nbytes);
-EXTERN size_t InflateSkip2(mat_t *mat, matvar_t *matvar, int nbytes);
-EXTERN size_t InflateSkipData(mat_t *mat,z_streamp z,enum matio_types data_type,int len);
-EXTERN size_t InflateVarTag(mat_t *mat, matvar_t *matvar, void *buf);
-EXTERN size_t InflateArrayFlags(mat_t *mat, matvar_t *matvar, void *buf);
-EXTERN size_t InflateRankDims(mat_t *mat, matvar_t *matvar, void *buf, size_t nbytes, mat_uint32_t** dims);
-EXTERN size_t InflateVarName(mat_t *mat,matvar_t *matvar,void *buf,int N);
-EXTERN size_t InflateDataTag(mat_t *mat, matvar_t *matvar, void *buf);
-EXTERN size_t InflateDataType(mat_t *mat, z_stream *z, void *buf);
-EXTERN size_t InflateData(mat_t *mat, z_streamp z, void *buf, unsigned int nBytes);
+EXTERN int InflateSkip(mat_t *mat, z_streamp z, int nBytes, size_t* bytesread);
+EXTERN int InflateSkipData(mat_t *mat, z_streamp z, enum matio_types data_type, int len);
+EXTERN int InflateRankDims(mat_t *mat, z_streamp z, void *buf, size_t nBytes, mat_uint32_t** dims, size_t* bytesread);
+EXTERN int Inflate(mat_t *mat, z_streamp z, void *buf, unsigned int nBytes, size_t* bytesread);
+EXTERN int InflateData(mat_t *mat, z_streamp z, void *buf, unsigned int nBytes);
 #endif
 
 /* mat.c */
 EXTERN mat_complex_split_t *ComplexMalloc(size_t nbytes);
+EXTERN void ComplexFree(mat_complex_split_t* complex_data);
 EXTERN enum matio_types ClassType2DataType(enum matio_classes class_type);
-EXTERN int SafeMulDims(const matvar_t *matvar, size_t* nelems);
-EXTERN int SafeMul(size_t* res, size_t a, size_t b);
-EXTERN int SafeAdd(size_t* res, size_t a, size_t b);
+EXTERN int Add(size_t* res, size_t a, size_t b);
+EXTERN int Mul(size_t* res, size_t a, size_t b);
+EXTERN int Mat_MulDims(const matvar_t *matvar, size_t* nelems);
+EXTERN int Read(void* buf, size_t size, size_t count, FILE* fp, size_t* bytesread);
+
+/* io.c */
+#if defined(_WIN32) && defined(_MSC_VER)
+EXTERN wchar_t* utf82u(const char* src);
+#endif
 
 #endif
