@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2019, Christopher C. Hulbert
+ * Copyright (c) 2012-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,9 +24,9 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "matio_private.h"
 #include <stdlib.h>
 #include <string.h>
-#include "matio_private.h"
 
 /** @brief Returns a pointer to the Cell array at a specific index
  *
@@ -42,13 +42,16 @@ Mat_VarGetCell(matvar_t *matvar,int index)
 {
     size_t nelems = 1;
     matvar_t *cell = NULL;
+    int err;
 
     if ( matvar == NULL )
         return NULL;
 
-    SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
+    if ( err )
+        return NULL;
 
-    if ( 0 <= index && index < nelems )
+    if ( 0 <= index && (size_t)index < nelems )
         cell = *((matvar_t **)matvar->data + index);
 
     return cell;
@@ -80,8 +83,7 @@ Mat_VarGetCells(matvar_t *matvar,int *start,int *stride,int *edge)
     size_t idx[10] = {0,}, cnt[10] = {0,}, dimp[10] = {0,};
     matvar_t **cells;
 
-    if ( (matvar == NULL) || (start == NULL) || (stride == NULL) ||
-        (edge == NULL) ) {
+    if ( matvar == NULL || start == NULL || stride == NULL || edge == NULL ) {
         return NULL;
     } else if ( matvar->rank > 9 ) {
         return NULL;
@@ -108,7 +110,7 @@ Mat_VarGetCells(matvar_t *matvar,int *start,int *stride,int *edge)
         cnt[1]++;
         idx[1] += stride[1];
         for ( j = 1; j < matvar->rank; j++ ) {
-            if ( cnt[j] == edge[j] ) {
+            if ( cnt[j] == (size_t)edge[j] ) {
                 cnt[j] = 0;
                 idx[j] = start[j];
                 if ( j < matvar->rank - 1 ) {
@@ -168,13 +170,17 @@ Mat_VarSetCell(matvar_t *matvar,int index,matvar_t *cell)
 {
     size_t nelems = 1;
     matvar_t **cells, *old_cell = NULL;
+    int err;
 
     if ( matvar == NULL || matvar->rank < 1 )
         return NULL;
 
-   SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
+    if ( err )
+        return NULL;
+
     cells = (matvar_t**)matvar->data;
-    if ( 0 <= index && index < nelems ) {
+    if ( 0 <= index && (size_t)index < nelems ) {
         old_cell = cells[index];
         cells[index] = cell;
     }
