@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2019, Christopher C. Hulbert
+ * Copyright (c) 2012-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,12 +24,12 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "matio_private.h"
 #include <stdlib.h>
 #include <string.h>
 #if defined(_MSC_VER) || defined(__MINGW32__)
 #   define strdup _strdup
 #endif
-#include "matio_private.h"
 
 /** @brief Creates a structure MATLAB variable with the given name and fields
  *
@@ -91,10 +91,12 @@ Mat_VarCreateStruct(const char *name,int rank,size_t *dims,const char **fields,
         }
         if ( NULL != matvar && nelems > 0 ) {
             size_t nelems_x_nfields;
-            int err = SafeMul(&nelems_x_nfields, nelems, nfields);
-            err |= SafeMul(&matvar->nbytes, nelems_x_nfields, matvar->data_size);
-            if ( err )
+            int err = Mul(&nelems_x_nfields, nelems, nfields);
+            err |= Mul(&matvar->nbytes, nelems_x_nfields, matvar->data_size);
+            if ( err ) {
+                Mat_VarFree(matvar);
                 return NULL;
+            }
             matvar->data = calloc(nelems_x_nfields, matvar->data_size);
         }
     }
@@ -124,12 +126,12 @@ Mat_VarAddStructField(matvar_t *matvar,const char *fieldname)
     if ( matvar == NULL || fieldname == NULL )
         return -1;
 
-    err = SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
     if ( err )
         return -1;
 
-    nfields = matvar->internal->num_fields+1;
-    matvar->internal->num_fields = nfields;
+    matvar->internal->num_fields++;
+    nfields = matvar->internal->num_fields;
     fieldnames = (char**)realloc(matvar->internal->fieldnames,
         nfields*sizeof(*matvar->internal->fieldnames));
     if ( NULL == fieldnames )
@@ -139,8 +141,8 @@ Mat_VarAddStructField(matvar_t *matvar,const char *fieldname)
 
     {
         size_t nelems_x_nfields;
-        err = SafeMul(&nelems_x_nfields, nelems, nfields);
-        err |= SafeMul(&matvar->nbytes, nelems_x_nfields, sizeof(*new_data));
+        err = Mul(&nelems_x_nfields, nelems, nfields);
+        err |= Mul(&matvar->nbytes, nelems_x_nfields, sizeof(*new_data));
         if ( err ) {
             matvar->nbytes = 0;
             return -1;
@@ -225,7 +227,7 @@ Mat_VarGetStructFieldByIndex(matvar_t *matvar,size_t field_index,size_t index)
         matvar->data_size == 0 )
         return NULL;
 
-    err = SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
     if ( err )
         return NULL;
 
@@ -265,7 +267,7 @@ Mat_VarGetStructFieldByName(matvar_t *matvar,const char *field_name,
         matvar->data_size == 0 )
         return NULL;
 
-    err = SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
     if ( err )
         return NULL;
 
@@ -307,9 +309,9 @@ Mat_VarGetStructField(matvar_t *matvar,void *name_or_index,int opt,int index)
     matvar_t *field = NULL;
     size_t nelems = 1;
 
-    err = SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
     nfields = matvar->internal->num_fields;
-    if ( index < 0 || (nelems > 0 && index >= nelems ))
+    if ( index < 0 || (nelems > 0 && (size_t)index >= nelems ))
         err = 1;
     else if ( nfields < 1 )
         err = 1;
@@ -355,8 +357,7 @@ Mat_VarGetStructs(matvar_t *matvar,int *start,int *stride,int *edge,
     matvar_t **fields, *struct_slab;
     int j;
 
-    if ( (matvar == NULL) || (start == NULL) || (stride == NULL) ||
-         (edge == NULL) ) {
+    if ( matvar == NULL || start == NULL || stride == NULL || edge == NULL ) {
         return NULL;
     } else if ( matvar->rank > 9 ) {
         return NULL;
@@ -408,7 +409,7 @@ Mat_VarGetStructs(matvar_t *matvar,int *start,int *stride,int *edge,
         cnt[1]++;
         idx[1] += stride[1];
         for ( j = 1; j < matvar->rank; j++ ) {
-            if ( cnt[j] == edge[j] ) {
+            if ( cnt[j] == (size_t)edge[j] ) {
                 cnt[j] = 0;
                 idx[j] = start[j];
                 if ( j < matvar->rank - 1 ) {
@@ -511,7 +512,7 @@ Mat_VarSetStructFieldByIndex(matvar_t *matvar,size_t field_index,size_t index,
         matvar->data == NULL )
         return NULL;
 
-    err = SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
     if ( err )
         return NULL;
 
@@ -553,7 +554,7 @@ Mat_VarSetStructFieldByName(matvar_t *matvar,const char *field_name,
          matvar->data == NULL )
         return NULL;
 
-    err = SafeMulDims(matvar, &nelems);
+    err = Mat_MulDims(matvar, &nelems);
     if ( err )
         return NULL;
 
