@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2019, Christopher C. Hulbert
+ * Copyright (c) 2005-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,16 +24,13 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "matio.h"
+#include <getopt.h>
 #include <stdlib.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
-#include <getopt.h>
-#include "matio.h"
-#if !defined(HAVE_STRCASECMP)
-#   define strcasecmp(a,b) strcmp(a,b)
-#endif
 #if defined(_MSC_VER) || defined(__MINGW32__)
 #   define SIZE_T_FMTSTR "Iu"
 #else
@@ -283,12 +280,12 @@ slab_select_valid(int rank,int *start,int *stride,int *edge,matvar_t *matvar)
             } else if ( edge[i] < 0 ) {
                 /* index of the form 1:stride:end */
                 edge[i] = (int)floor((double)(matvar->dims[i]-start[i]-1) / (double)stride[i])+1;
-            } else if ( edge[i] > matvar->dims[i] ) {
+            } else if ( (size_t)edge[i] > matvar->dims[i] ) {
                 /* edge can't be bigger than the size of the dimension */
                 fprintf(stderr,"edge out of bound on dimension %d",i+1);
                 valid = 0;
                 break;
-            } else if ( start[i] >= matvar->dims[i] ||
+            } else if ( (size_t)start[i] >= matvar->dims[i] ||
                         (start[i] > edge[i] && edge[i] > 0) ) {
                 /* Start can't be bigger than the size of the dimension and
                  * can't be greater than the edge unless edge == -1 => end
@@ -324,10 +321,10 @@ read_selected_data(mat_t *mat,matvar_t **_matvar,char *index_str)
     while ( !done ) {
         /* Check If the user is selecting a subset of the dataset */
         if ( next_tok == '(' ) {
-            int rank, *start, *stride, *edge,nmemb;
+            int rank, *start, *stride, *edge, nmemb;
 
-            open    = next_tok_pos;
-            close   = strchr(open+1,')');
+            open  = next_tok_pos;
+            close = strchr(open+1,')');
 
             /* Get the next token after this selection */
             next_tok_pos = get_next_token(close+1);
@@ -385,7 +382,7 @@ read_selected_data(mat_t *mat,matvar_t **_matvar,char *index_str)
                         matvar->dims[1] = 1;
                     }
                 } else {
-                    Mat_VarReadData(mat,matvar,matvar->data,start,stride,edge);
+                    err = Mat_VarReadData(mat,matvar,matvar->data,start,stride,edge);
                     for ( i = 0; i < rank; i++ )
                         matvar->dims[i] = (size_t)edge[i];
                 }
@@ -417,7 +414,7 @@ read_selected_data(mat_t *mat,matvar_t **_matvar,char *index_str)
                 Mat_VarFree(matvar);
                 matvar = field;
                 if ( done == 1 ) {
-                    Mat_VarReadDataAll(mat, matvar);
+                    err = Mat_VarReadDataAll(mat, matvar);
                 }
             } else if ( matvar->class_type == MAT_C_CELL ) {
                 int ncells;
@@ -457,7 +454,7 @@ read_selected_data(mat_t *mat,matvar_t **_matvar,char *index_str)
                 break;
             }
         } else if ( next_tok == '{' ) {
-            int rank, *start, *stride, *edge,nmemb, err = 0;
+            int rank, *start, *stride, *edge, nmemb;
 
             if ( matvar->class_type != MAT_C_CELL ) {
                 fprintf(stderr,"Only Cell Arrays can index with {}");
@@ -572,12 +569,12 @@ print_whos(matvar_t *matvar)
     return;
 }
 
-static int indent = 0;
+static size_t indent = 0;
 
 static void
 default_printf_func(int log_level,char *message)
 {
-    int i;
+    size_t i;
 
     for ( i = 0; i < indent; i++ )
         printf("    ");
@@ -690,7 +687,7 @@ print_default_numeric_3d(matvar_t *matvar)
         char *rp = (char*)complex_data->Re;
         char *ip = (char*)complex_data->Im;
         for ( k = 0; k < matvar->dims[2]; k++ ) {
-            Mat_Message("%s(:,:,%lu) = ",matvar->name,k);
+            Mat_Message("%s(:,:,%" SIZE_T_FMTSTR ") = ",matvar->name,k);
             indent++;
             for ( i = 0; i < matvar->dims[0]; i++ ) {
                 for ( l = 0; l < indent; l++ )
@@ -710,7 +707,7 @@ print_default_numeric_3d(matvar_t *matvar)
     } else {
         char *data = (char*)matvar->data;
         for ( k = 0; k < matvar->dims[2]; k++ ) {
-            Mat_Message("%s(:,:,%lu) = ",matvar->name,k);
+            Mat_Message("%s(:,:,%" SIZE_T_FMTSTR ") = ",matvar->name,k);
             indent++;
             for ( i = 0; i < matvar->dims[0]; i++ ) {
                 for ( l = 0; l < indent; l++ )
@@ -787,10 +784,11 @@ print_default(matvar_t *matvar)
                 Mat_Message("Fields[%d] {", nfields);
                 indent++;
                 {
+                    size_t j;
                     matvar_t **fields = (matvar_t **)matvar->data;
                     if ( NULL != fields )
-                        for ( i = 0; i < nfields*nmemb; i++ )
-                            print_default(fields[i]);
+                        for ( j = 0; j < nfields*nmemb; j++ )
+                            print_default(fields[j]);
                 }
                 indent--;
                 Mat_Message("}");
@@ -814,10 +812,11 @@ print_default(matvar_t *matvar)
             Mat_Message("{");
             indent++;
             {
+                size_t j;
                 matvar_t **cells = (matvar_t **)matvar->data;
                 if ( NULL != cells )
-                    for ( i = 0; i < ncells; i++ )
-                        print_default(cells[i]);
+                    for ( j = 0; j < ncells; j++ )
+                        print_default(cells[j]);
             }
             indent--;
             Mat_Message("}");
@@ -880,7 +879,7 @@ main (int argc, char *argv[])
                 exit(EXIT_SUCCESS);
             case 'V':
                 printf("%s %s\nWritten by Christopher Hulbert\n\n"
-                       "Copyright(C) 2006-2019, Christopher C. Hulbert\n",
+                       "Copyright(C) 2006-2020, Christopher C. Hulbert\n",
                        prog_name,MATIO_VERSION_STR);
                 exit(EXIT_SUCCESS);
             default:
@@ -918,7 +917,7 @@ main (int argc, char *argv[])
                 if ( printdata ) {
                     if ( next_tok == '\0' ) {
                         /* No indexing tokens found, so read all of the data */
-                        Mat_VarReadDataAll(mat,matvar);
+                        err = Mat_VarReadDataAll(mat,matvar);
                     } else {
                         *next_tok_pos = next_tok;
                         read_selected_data(mat,&matvar,next_tok_pos);
