@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2019, Christopher C. Hulbert
+ * Copyright (c) 2012-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -64,6 +64,13 @@
 #undef HAVE_INTTYPES_H
 #endif
 
+/* Define to 1 if you have the <intsafe.h> header file. */
+#if defined(_MSC_VER) && _MSC_VER >= 1600
+#define HAVE_INTSAFE_H 1
+#else
+#undef HAVE_INTSAFE_H
+#endif
+
 /* Define to 1 if you have the `m' library (-lm). */
 #undef HAVE_LIBM
 
@@ -218,6 +225,9 @@
 /* Debug disabled */
 #undef NODEBUG
 
+/* Fixed types in safe-math.h disabled */
+#define PSNIP_SAFE_NO_FIXED 1
+
 /* Name of package */
 #define PACKAGE "matio"
 
@@ -228,7 +238,7 @@
 #define PACKAGE_NAME "MATIO"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "MATIO 1.5.17"
+#define PACKAGE_STRING "MATIO 1.5.19"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "matio"
@@ -237,7 +247,7 @@
 #define PACKAGE_URL "https://sourceforge.net/projects/matio"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "1.5.17"
+#define PACKAGE_VERSION "1.5.19"
 
 /* The size of `char', as computed by sizeof. */
 #define SIZEOF_CHAR 1
@@ -276,7 +286,7 @@
 #undef STDC_HEADERS
 
 /* Version number of package */
-#define VERSION "1.5.17"
+#define VERSION "1.5.19"
 
 /* Z prefix */
 #undef Z_PREFIX
