@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010-2019, Christopher C. Hulbert
+ * Copyright (c) 2010-2020, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,13 +34,13 @@
 #define MATIO_MINOR_VERSION 5
 
 /* Matio release level number */
-#define MATIO_RELEASE_LEVEL 17
+#define MATIO_RELEASE_LEVEL 19
 
 /* Matio version number */
-#define MATIO_VERSION 1517
+#define MATIO_VERSION 1519
 
 /* Matio version string */
-#define MATIO_VERSION_STR "1.5.17"
+#define MATIO_VERSION_STR "1.5.19"
 
 /* Default file format */
 #define MAT_FT_DEFAULT MAT_FT_MAT5
@@ -123,6 +123,9 @@
 
 #if MATIO_HAVE_STDINT_H
 #   include <stdint.h>
+#else
+#   include "stdint_msvc.h"
+#define MATIO_HAVE_STDINT_H 1
 #endif
 
 #ifdef _mat_int64_t
@@ -150,7 +153,7 @@
     typedef _mat_uint8_t mat_uint8_t;
 #endif
 
-/* 
+/*
   The following macros handle noreturn attributes according to the latest
   C11/C++11 standard with fallback to the MSVC extension if using an older
   compiler.
